@@ -1,6 +1,4 @@
 #!/usr/bin/env python
-from __future__ import print_function
-
 import os
 import json
 from os.path import abspath, isfile, join, expanduser
@@ -13,39 +11,42 @@ except ImportError:
     from urllib2 import Request, HTTPError, urlopen
 
 
-__version__ = "1.1.1"
+__version__ = "1.2.0"
 TINY_URL = "http://api.tinypng.org/api/shrink"
 
 _invalid_keys = set()
 
 
 def read_keyfile(filepath):
-    with open(filepath) as kf:
+    with open(filepath, 'r') as kf:
         return [k.strip() for k in kf.readlines()]
 
 
-def find_keys(opts=None, args=None):
+def find_keys(args=None):
     """Get keys specified in arguments
 
     returns list of keys or None
     """
-    if opts and opts.key:
-        return [opts.key]
+    key = args['--key']
+    if key:
+        return [key]
 
-    if opts and opts.apikeys:
-        return read_keyfile(opts.apikeys)
+    keyfile = args['--apikeys']
+    if keyfile:
+        return read_keyfile(keyfile)
 
     envkey = os.environ.get('TINYPNG_API_KEY', None)
     if envkey:
         return [envkey]
 
     local_keys = join(abspath("."), "tinypng.keys")
-    home_keys = join(expanduser("~/.tinypng.keys"))
 
     if isfile(local_keys):
         return read_keyfile(local_keys)
+
+    home_keys = join(expanduser("~/.tinypng.keys"))
     if isfile(home_keys):
-        return read_keyfile(local_keys)
+        return read_keyfile(home_keys)
 
     return None
 
@@ -63,6 +64,7 @@ def _shrink_info(in_data, api_key):
     enc_key = standard_b64encode(raw_key).decode('ascii')
     request = Request(TINY_URL, in_data)
     request.add_header("Authorization", "Basic %s" % enc_key)
+    request.add_header("X-PY-TinyPng", __version__)
 
     try:
         result = urlopen(request)
@@ -76,6 +78,10 @@ def _shrink_info(in_data, api_key):
 
 
 def shrink_info(in_data, api_key=None):
+    """Shrink binary data of a png
+
+    returns api_info
+    """
     if api_key:
         return _shrink_info(in_data, api_key)
 
@@ -90,6 +96,10 @@ def shrink_info(in_data, api_key=None):
 
 
 def shrink_data(in_data, api_key=None):
+    """Shrink binary data of a png
+
+    returns (api_info, shrunk_data)
+    """
     info = shrink_info(in_data, api_key)
     out_url = info['output']['url']
     try:
@@ -105,6 +115,11 @@ def shrink_data(in_data, api_key=None):
 
 
 def shrink_file(in_filepath, api_key=None, out_filepath=None):
+    """Shrink png file and write it back to a new file
+
+    The default file path replaces ".png" with ".tiny.png".
+    returns api_info (including info['ouput']['filepath'])
+    """
     if out_filepath is None:
         out_filepath = in_filepath
         if out_filepath.endswith(".png"):
